==> sfml-2.6.0-3-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/enumvalues_f.js <==
var searchData=
[
  ['p_0',['P',['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142aaeac1db209a64a0221277a835de986e6',1,'sf::Keyboard::P'],['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a0943cf62e03a8616a8a41b72539ded38',1,'sf::Keyboard::Scan::P']]],
  ['pagedown_1',['PageDown',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a395ec644184fe789a12ee2ed98d19ee3',1,'sf::Keyboard::Scan::PageDown'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a21c73323d9a8b6017f3bac0cb8c8ac1a',1,'sf::Keyboard::PageDown']]],
  ['pagetypeunknown_2',['PageTypeUnknown',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3bad220bc12dc45593af6e5079ea6c532c3',1,'sf::Ftp::Response']]],
  ['pageup_3',['PageUp',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a0c1f655bf99a3c7d2052814385fb222d',1,'sf::Keyboard::Scan::PageUp'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142aa24fe33bba1c3639c3aeaa317bd89d7e',1,'sf::Keyboard::PageUp']]],
  ['parameternotimplemented_4',['ParameterNotImplemented',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba8807473b8590e1debfb3740b7a3d081c',1,'sf::Ftp::Response']]],
  ['parametersunknown_5',['ParametersUnknown',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3baf4c7c88815981bbb7c3a3461f9f48b67',1,'sf::Ftp::Response']]],
  ['partial_6',['Partial',['../classsf_1_1Socket.html#a51bf0fd51057b98a10fbb866246176dca181c163fad2eaea927185d127c392706',1,'sf::Socket']]],
  ['partialcontent_7',['PartialContent',['../classsf_1_1Http_1_1Response.html#a663e071978e30fbbeb20ed045be874d8a0cfae3ab0469b73dfddc54312a5e6a8a',1,'sf::Http::Response']]],
  ['paste_8',['Paste',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875ab5417583410afc02cad51e66cb97b196',1,'sf::Keyboard::Scan']]],
  ['pause_9',['Pause',['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a95daf340fcc3d5c2846f69d184170d9b',1,'sf::Keyboard::Pause'],['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a40a805122e3ce91bde95d98ac43be234',1,'sf::Keyboard::Scan::Pause']]],
  ['paused_10',['Paused',['../classsf_1_1SoundSource.html#ac43af72c98c077500b239bc75b812f03ac3ca1fcc0394267c9bdbe3dc0a8a7e41',1,'sf::SoundSource']]],
  ['period_11',['Period',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875ae09b8ab0fa58ee31f499678d3e93a411',1,'sf::Keyboard::Scan::Period'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142ac72ba959ab1946957e8dfd4f81ea811d',1,'sf::Keyboard::Period']]],
  ['pixels_12',['Pixels',['../classsf_1_1Texture.html#aa6fd3bbe3c334b3c4428edfb2765a82ea6372f9c3a10203a7a69d8d5da59d82ff',1,'sf::Texture']]],
  ['playing_13',['Playing',['../classsf_1_1SoundSource.html#ac43af72c98c077500b239bc75b812f03af07bdea9f70ef7606dfc9f955beeee18',1,'sf::SoundSource']]],
  ['pointlesscommand_14',['PointlessCommand',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba38adc424f1adcd332745de8cd3b7737a',1,'sf::Ftp::Response']]],
  ['points_15',['Points',['../group__graphics.html#gga5ee56ac1339984909610713096283b1bac7097d3e01778b9318def1f7ac35a785',1,'sf']]],
  ['post_16',['Post',['../classsf_1_1Http_1_1Request.html#a620f8bff6f43e1378f321bf53fbf5598ae8ec4048b9550f8d0747d4199603141a',1,'sf::Http::Request']]],
  ['povx_17',['PovX',['../classsf_1_1Joystick.html#a48db337092c2e263774f94de6d50baa7a06420f7714e4dfd8b841885a0b5f3954',1,'sf::Joystick']]],
  ['povy_18',['PovY',['../classsf_1_1Joystick.html#a48db337092c2e263774f94de6d50baa7a0f8ffb2dcddf91b98ab910a4f8327ad9',1,'sf::Joystick']]],
  ['printscreen_19',['PrintScreen',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a8699683af17a0a4031bccf52f5222302',1,'sf::Keyboard::Scan']]],
  ['put_20',['Put',['../classsf_1_1Http_1_1Request.html#a620f8bff6f43e1378f321bf53fbf5598a523b94f9af069c1f35061d32011e2495',1,'sf::Http::Request']]]
];

==> sfml-2.6.1-1-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/enumvalues_f.js <==
var searchData=
[
  ['p_0',['p',['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142aaeac1db209a64a0221277a835de986e6',1,'sf::Keyboard::P'],['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a0943cf62e03a8616a8a41b72539ded38',1,'sf::Keyboard::Scan::P']]],
  ['pagedown_1',['pagedown',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a395ec644184fe789a12ee2ed98d19ee3',1,'sf::Keyboard::Scan::PageDown'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a21c73323d9a8b6017f3bac0cb8c8ac1a',1,'sf::Keyboard::PageDown']]],
  ['pagetypeunknown_2',['PageTypeUnknown',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3bad220bc12dc45593af6e5079ea6c532c3',1,'sf::Ftp::Response']]],
  ['pageup_3',['pageup',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a0c1f655bf99a3c7d2052814385fb222d',1,'sf::Keyboard::Scan::PageUp'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142aa24fe33bba1c3639c3aeaa317bd89d7e',1,'sf::Keyboard::PageUp']]],
  ['parameternotimplemented_4',['ParameterNotImplemented',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba8807473b8590e1debfb3740b7a3d081c',1,'sf::Ftp::Response']]],
  ['parametersunknown_5',['ParametersUnknown',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3baf4c7c88815981bbb7c3a3461f9f48b67',1,'sf::Ftp::Response']]],
  ['partial_6',['Partial',['../classsf_1_1Socket.html#a51bf0fd51057b98a10fbb866246176dca181c163fad2eaea927185d127c392706',1,'sf::Socket']]],
  ['partialcontent_7',['PartialContent',['../classsf_1_1Http_1_1Response.html#a663e071978e30fbbeb20ed045be874d8a0cfae3ab0469b73dfddc54312a5e6a8a',1,'sf::Http::Response']]],
  ['paste_8',['Paste',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875ab5417583410afc02cad51e66cb97b196',1,'sf::Keyboard::Scan']]],
  ['pause_9',['pause',['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a95daf340fcc3d5c2846f69d184170d9b',1,'sf::Keyboard::Pause'],['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a40a805122e3ce91bde95d98ac43be234',1,'sf::Keyboard::Scan::Pause']]],
  ['paused_10',['Paused',['../classsf_1_1SoundSource.html#ac43af72c98c077500b239bc75b812f03ac3ca1fcc0394267c9bdbe3dc0a8a7e41',1,'sf::SoundSource']]],
  ['period_11',['period',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875ae09b8ab0fa58ee31f499678d3e93a411',1,'sf::Keyboard::Scan::Period'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142ac72ba959ab1946957e8dfd4f81ea811d',1,'sf::Keyboard::Period']]],
  ['pixels_12',['Pixels',['../classsf_1_1Texture.html#aa6fd3bbe3c334b3c4428edfb2765a82ea6372f9c3a10203a7a69d8d5da59d82ff',1,'sf::Texture']]],
  ['playing_13',['Playing',['../classsf_1_1SoundSource.html#ac43af72c98c077500b239bc75b812f03af07bdea9f70ef7606dfc9f955beeee18',1,'sf::SoundSource']]],
  ['pointlesscommand_14',['PointlessCommand',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba38adc424f1adcd332745de8cd3b7737a',1,'sf::Ftp::Response']]],
  ['points_15',['Points',['../group__graphics.html#gga5ee56ac1339984909610713096283b1bac7097d3e01778b9318def1f7ac35a785',1,'sf']]],
  ['post_16',['Post',['../classsf_1_1Http_1_1Request.html#a620f8bff6f43e1378f321bf53fbf5598ae8ec4048b9550f8d0747d4199603141a',1,'sf::Http::Request']]],
  ['povx_17',['PovX',['../classsf_1_1Joystick.html#a48db337092c2e263774f94de6d50baa7a06420f7714e4dfd8b841885a0b5f3954',1,'sf::Joystick']]],
  ['povy_18',['PovY',['../classsf_1_1Joystick.html#a48db337092c2e263774f94de6d50baa7a0f8ffb2dcddf91b98ab910a4f8327ad9',1,'sf::Joystick']]],
  ['printscreen_19',['PrintScreen',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875a8699683af17a0a4031bccf52f5222302',1,'sf::Keyboard::Scan']]],
  ['put_20',['Put',['../classsf_1_1Http_1_1Request.html#a620f8bff6f43e1378f321bf53fbf5598a523b94f9af069c1f35061d32011e2495',1,'sf::Http::Request']]]
];
